:description: Different strategies to implement realtime in Django.

Realtime in Django: Websockets, SSE, Polling
============================================

.. warning::

    Work in progress. To receive updates `subscribe to this discussion <https://github.com/Tobi-De/falco/discussions/39>`_ or
    follow me on `x <https://twitter.com/tobidegnon>`_ or `mastodon <https://fosstodon.org/@tobide>`_.

Usually when someone use the term **realtime** in web development, they mean `websocket <https://developer.mozilla.org/en-US/docs/Web/API/WebSockets_API>`_ but
websocket is not the simplest **realtime** technology out there so it will be our last resort.

Polling and long polling
------------------------

Server sent events
------------------

SSE back and forth with htmx
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Websocket with channels
-----------------------
